@@ -1,4 +1,4 @@
-#!/usr/bin/python2.7
+#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
 import time
@@ -12,7 +12,7 @@ class Attack(object):
         self.target = target
 
     def run(self):
-        raise Exception("Unimplemented method: run")
+        raise Exception('Unimplemented method: run')
 
     def wait_for_target(self, airodump):
         '''Waits for target to appear in airodump.'''
